@@ -36,6 +36,7 @@ from .type_defs import (
     CreateReadinessCheckResponseTypeDef,
     CreateRecoveryGroupResponseTypeDef,
     CreateResourceSetResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     GetArchitectureRecommendationsResponseTypeDef,
     GetCellReadinessSummaryResponseTypeDef,
     GetCellResponseTypeDef,
@@ -111,6 +112,14 @@ class Route53RecoveryReadinessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client/#close)
+        """
+
     def create_cell(
         self, *, CellName: str, Cells: Sequence[str] = ..., Tags: Mapping[str, str] = ...
     ) -> CreateCellResponseTypeDef:
@@ -156,7 +165,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         *,
         ResourceSetName: str,
         ResourceSetType: str,
-        Resources: Sequence["ResourceTypeDef"],
+        Resources: Sequence[ResourceTypeDef],
         Tags: Mapping[str, str] = ...
     ) -> CreateResourceSetResponseTypeDef:
         """
@@ -166,7 +175,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client/#create_resource_set)
         """
 
-    def delete_cell(self, *, CellName: str) -> None:
+    def delete_cell(self, *, CellName: str) -> EmptyResponseMetadataTypeDef:
         """
         Delete a cell.
 
@@ -184,7 +193,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client/#delete_cross_account_authorization)
         """
 
-    def delete_readiness_check(self, *, ReadinessCheckName: str) -> None:
+    def delete_readiness_check(self, *, ReadinessCheckName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a readiness check.
 
@@ -192,7 +201,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client/#delete_readiness_check)
         """
 
-    def delete_recovery_group(self, *, RecoveryGroupName: str) -> None:
+    def delete_recovery_group(self, *, RecoveryGroupName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a recovery group.
 
@@ -200,7 +209,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client/#delete_recovery_group)
         """
 
-    def delete_resource_set(self, *, ResourceSetName: str) -> None:
+    def delete_resource_set(self, *, ResourceSetName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a resource set.
 
@@ -392,7 +401,9 @@ class Route53RecoveryReadinessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client/#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> None:
+    def untag_resource(
+        self, *, ResourceArn: str, TagKeys: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes a tag from a resource.
 
@@ -430,7 +441,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
 
     def update_resource_set(
-        self, *, ResourceSetName: str, ResourceSetType: str, Resources: Sequence["ResourceTypeDef"]
+        self, *, ResourceSetName: str, ResourceSetType: str, Resources: Sequence[ResourceTypeDef]
     ) -> UpdateResourceSetResponseTypeDef:
         """
         Updates a resource set.
