@@ -39,8 +39,7 @@ Usage::
 """
 from typing import Generic, Iterator, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     GetCellReadinessSummaryResponseTypeDef,
@@ -80,14 +79,14 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class GetCellReadinessSummaryPaginator(Boto3Paginator):
+class GetCellReadinessSummaryPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetCellReadinessSummary)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators/#getcellreadinesssummarypaginator)
     """
 
     def paginate(
-        self, *, CellName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, CellName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetCellReadinessSummaryResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetCellReadinessSummary.paginate)
@@ -95,7 +94,7 @@ class GetCellReadinessSummaryPaginator(Boto3Paginator):
         """
 
 
-class GetReadinessCheckResourceStatusPaginator(Boto3Paginator):
+class GetReadinessCheckResourceStatusPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetReadinessCheckResourceStatus)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators/#getreadinesscheckresourcestatuspaginator)
@@ -106,7 +105,7 @@ class GetReadinessCheckResourceStatusPaginator(Boto3Paginator):
         *,
         ReadinessCheckName: str,
         ResourceIdentifier: str,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetReadinessCheckResourceStatusResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetReadinessCheckResourceStatus.paginate)
@@ -114,14 +113,14 @@ class GetReadinessCheckResourceStatusPaginator(Boto3Paginator):
         """
 
 
-class GetReadinessCheckStatusPaginator(Boto3Paginator):
+class GetReadinessCheckStatusPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetReadinessCheckStatus)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators/#getreadinesscheckstatuspaginator)
     """
 
     def paginate(
-        self, *, ReadinessCheckName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, ReadinessCheckName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetReadinessCheckStatusResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetReadinessCheckStatus.paginate)
@@ -129,14 +128,14 @@ class GetReadinessCheckStatusPaginator(Boto3Paginator):
         """
 
 
-class GetRecoveryGroupReadinessSummaryPaginator(Boto3Paginator):
+class GetRecoveryGroupReadinessSummaryPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetRecoveryGroupReadinessSummary)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators/#getrecoverygroupreadinesssummarypaginator)
     """
 
     def paginate(
-        self, *, RecoveryGroupName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, RecoveryGroupName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetRecoveryGroupReadinessSummaryResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetRecoveryGroupReadinessSummary.paginate)
@@ -144,14 +143,14 @@ class GetRecoveryGroupReadinessSummaryPaginator(Boto3Paginator):
         """
 
 
-class ListCellsPaginator(Boto3Paginator):
+class ListCellsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListCells)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators/#listcellspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListCellsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListCells.paginate)
@@ -159,14 +158,14 @@ class ListCellsPaginator(Boto3Paginator):
         """
 
 
-class ListCrossAccountAuthorizationsPaginator(Boto3Paginator):
+class ListCrossAccountAuthorizationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListCrossAccountAuthorizations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators/#listcrossaccountauthorizationspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListCrossAccountAuthorizationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListCrossAccountAuthorizations.paginate)
@@ -174,14 +173,14 @@ class ListCrossAccountAuthorizationsPaginator(Boto3Paginator):
         """
 
 
-class ListReadinessChecksPaginator(Boto3Paginator):
+class ListReadinessChecksPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListReadinessChecks)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators/#listreadinesscheckspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListReadinessChecksResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListReadinessChecks.paginate)
@@ -189,14 +188,14 @@ class ListReadinessChecksPaginator(Boto3Paginator):
         """
 
 
-class ListRecoveryGroupsPaginator(Boto3Paginator):
+class ListRecoveryGroupsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListRecoveryGroups)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators/#listrecoverygroupspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRecoveryGroupsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListRecoveryGroups.paginate)
@@ -204,14 +203,14 @@ class ListRecoveryGroupsPaginator(Boto3Paginator):
         """
 
 
-class ListResourceSetsPaginator(Boto3Paginator):
+class ListResourceSetsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListResourceSets)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators/#listresourcesetspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListResourceSetsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListResourceSets.paginate)
@@ -219,14 +218,14 @@ class ListResourceSetsPaginator(Boto3Paginator):
         """
 
 
-class ListRulesPaginator(Boto3Paginator):
+class ListRulesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListRules)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators/#listrulespaginator)
     """
 
     def paginate(
-        self, *, ResourceType: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, ResourceType: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRulesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListRules.paginate)
